darkhistory.physics.d_xe_Saha_dz — DarkHistory documentation

# darkhistory.physics.d_xe_Saha_dz

`darkhistory.physics.` `d_xe_Saha_dz`(rs, species)

  z-derivative of the Saha equilibrium ionization value.

  Parameters: | rs : float The redshift in 1+z. species : {‘singlet’, ‘triplet’}
  Returns: | float The derivative of the Saha equilibrium d xe/dz.

  Notes

  See astro-ph/9909275 and 1011.3758 for details.

#### Previous topic

darkhistory.physics.xe_Saha

#### Next topic

darkhistory.physics.photo_ion_rate

### This Page

Show Source